/**
 * Copyright (c) 2007-2012 EBM WebSourcing, 2012-2017 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.samples.pojo;

import java.util.logging.Level;
import java.util.logging.Logger;

import javax.jbi.component.ComponentContext;
import javax.jbi.messaging.DeliveryChannel;
import javax.jbi.messaging.MessagingException;
import javax.xml.transform.Source;

import org.ow2.petals.component.framework.api.exception.PEtALSCDKException;
import org.ow2.petals.component.framework.api.message.Exchange;
import org.ow2.petals.component.framework.listener.AbstractJBIListener;
import org.ow2.petals.component.framework.util.SourceUtil;

public class SamplePojoService {

    private Logger logger;

    private ComponentContext ctx;

    private DeliveryChannel channel;

    public void setChannel(final DeliveryChannel channel) {
        this.channel = channel;
    }

    public void setCtx(final ComponentContext ctx) {
        this.ctx = ctx;
    }

    public void setLogger(final Logger logger) {
        this.logger = logger;
    }

    public boolean onExchange(final Exchange exchange, final AbstractJBIListener jbiListener)
            throws MessagingException, PEtALSCDKException {
        this.logger.info("SamplePojoService receives an echange");
        if (exchange.isInMessage()) {
            final Source inSource = exchange.getInMessageContentAsSource();
            this.logger.info("The SamplePojo received:\n" + SourceUtil.createString(inSource));

            // answer
            if (exchange.isInOutPattern() || exchange.isInOptionalOutPattern()) {
                exchange.setOutMessageContent(inSource);
            }
        } else {
            exchange.setError(new MessagingException("No IN message!"));
        }

        return true;
    }

    public void init() {
        this.logger.log(Level.INFO, "SamplePojo inits.");
    }

}
